pub type SignRegistryHandle = Arc<ArcSwap<SignRegistry>>;Expand description
Register and look up with this exact alias (the ServiceRegistry TypeId
rule).
Aliased Type
pub struct SignRegistryHandle { /* private fields */ }pub type SignRegistryHandle = Arc<ArcSwap<SignRegistry>>;Register and look up with this exact alias (the ServiceRegistry TypeId
rule).
pub struct SignRegistryHandle { /* private fields */ }