register_table_mode

Function register_table_mode 

pub fn register_table_mode(registry: &mut ModeRegistry)
Register TableMode in registry. Called by register_foundation_modes; the chords’ bodies are registered separately by register_table_actions into the command registry, which must happen before the host translates mode keymaps or the entries’ command names will not resolve.

Panics

If table-mode is already registered.